@@ -5,9 +5,9 @@
 //              with the application.
 // ---------------------------------------------------------------------------
 // $Source: src/binops/div.rs $
-// $Revision: 2021-11-29T14:49:18+01:00 $
+// $Revision: 2022-01-02T11:24:00+01:00 $
 
-use std::{
+use core::{
     cmp::Ordering,
     ops::{Div, DivAssign},
 };
@@ -86,22 +86,18 @@ pub(crate) fn div(
 impl Div<Decimal> for Decimal {
     type Output = Decimal;
 
-    fn div(self, other: Decimal) -> Self::Output {
-        if other.eq_zero() {
+    fn div(self, rhs: Decimal) -> Self::Output {
+        if rhs.eq_zero() {
             panic!("{}", DecimalError::DivisionByZero);
         }
         if self.eq_zero() {
             return Self::ZERO;
         }
-        if other.eq_one() {
+        if rhs.eq_one() {
             return self;
         }
-        match div(
-            self.coeff,
-            self.n_frac_digits,
-            other.coeff,
-            other.n_frac_digits,
-        ) {
+        match div(self.coeff, self.n_frac_digits, rhs.coeff, rhs.n_frac_digits)
+        {
             Ok((coeff, n_frac_digits)) => Self::Output {
                 coeff,
                 n_frac_digits,
@@ -124,23 +120,23 @@ mod div_decimal_tests {
         let x = Decimal::new_raw(-1000, 9);
         let y = Decimal::new_raw(-4, 0);
         let z = x / y;
-        assert_eq!(z.coeff, 25);
-        assert_eq!(z.n_frac_digits, 8);
+        assert_eq!(z.coefficient(), 25);
+        assert_eq!(z.n_frac_digits(), 8);
         let x = Decimal::new_raw(17, 0);
         let y = Decimal::new_raw(-200, 2);
         let z = x / y;
-        assert_eq!(z.coeff, -85);
-        assert_eq!(z.n_frac_digits, 1);
+        assert_eq!(z.coefficient(), -85);
+        assert_eq!(z.n_frac_digits(), 1);
         let x = Decimal::new_raw(17, 8);
         let y = Decimal::new_raw(2, 0);
         let z = x / y;
-        assert_eq!(z.coeff, 85);
-        assert_eq!(z.n_frac_digits, 9);
+        assert_eq!(z.coefficient(), 85);
+        assert_eq!(z.n_frac_digits(), 9);
         let x = Decimal::new_raw(12345678901234567890, 2);
         let y = Decimal::new_raw(244140625, 6);
         let z = x / y;
-        assert_eq!(z.coeff, 5056790077945679007744);
-        assert_eq!(z.n_frac_digits, 7);
+        assert_eq!(z.coefficient(), 5056790077945679007744);
+        assert_eq!(z.n_frac_digits(), 7);
     }
 
     #[test]
@@ -148,8 +144,8 @@ mod div_decimal_tests {
         let x = Decimal::new_raw(0, 9);
         let y = Decimal::new_raw(8, 0);
         let z = x / y;
-        assert_eq!(z.coeff, 0);
-        assert_eq!(z.n_frac_digits, 0);
+        assert_eq!(z.coefficient(), 0);
+        assert_eq!(z.n_frac_digits(), 0);
     }
 
     #[test]
@@ -157,12 +153,12 @@ mod div_decimal_tests {
         let x = Decimal::new_raw(17, 5);
         let y = Decimal::ONE;
         let z = x / y;
-        assert_eq!(z.coeff, 17);
-        assert_eq!(z.n_frac_digits, 5);
+        assert_eq!(z.coefficient(), 17);
+        assert_eq!(z.n_frac_digits(), 5);
         let y = Decimal::new_raw(1000000000000000, 15);
         let z = x / y;
-        assert_eq!(z.coeff, 17);
-        assert_eq!(z.n_frac_digits, 5);
+        assert_eq!(z.coefficient(), 17);
+        assert_eq!(z.n_frac_digits(), 5);
     }
 
     #[test]
@@ -202,9 +198,9 @@ mod div_decimal_tests {
         let x = Decimal::new_raw(12345, 3);
         let y = Decimal::new_raw(12345, 1);
         let z = x / y;
-        assert_eq!(z.coeff, (&x / y).coeff);
-        assert_eq!(z.coeff, (x / &y).coeff);
-        assert_eq!(z.coeff, (&x / &y).coeff);
+        assert_eq!(z.coefficient(), (&x / y).coefficient());
+        assert_eq!(z.coefficient(), (x / &y).coefficient());
+        assert_eq!(z.coefficient(), (&x / &y).coefficient());
     }
 }
 
@@ -217,20 +213,20 @@ macro_rules! impl_div_decimal_and_int {
         impl Div<$t> for Decimal {
             type Output = Decimal;
 
-            fn div(self, other: $t) -> Self::Output {
-                if other == 0 {
+            fn div(self, rhs: $t) -> Self::Output {
+                if rhs == 0 {
                     panic!("{}", DecimalError::DivisionByZero);
                 }
                 if self.eq_zero() {
                     return Self::ZERO;
                 }
-                if other == 1 {
+                if rhs == 1 {
                     return self;
                 }
                 match div(
                     self.coeff,
                     self.n_frac_digits,
-                    other as i128,
+                    rhs as i128,
                     0,
                 ) {
                     Ok((coeff, n_frac_digits)) => Self::Output {
@@ -245,14 +241,14 @@ macro_rules! impl_div_decimal_and_int {
         impl Div<Decimal> for $t {
             type Output = Decimal;
 
-            fn div(self, other: Decimal) -> Self::Output {
-                if other.eq_zero() {
+            fn div(self, rhs: Decimal) -> Self::Output {
+                if rhs.eq_zero() {
                     panic!("{}", DecimalError::DivisionByZero);
                 }
                 if self == 0 {
                     return Decimal::ZERO;
                 }
-                if other.eq_one() {
+                if rhs.eq_one() {
                     return Self::Output {
                         coeff: self as i128,
                         n_frac_digits: 0,
@@ -261,8 +257,8 @@ macro_rules! impl_div_decimal_and_int {
                 match div(
                     self as i128,
                     0,
-                    other.coeff,
-                    other.n_frac_digits,
+                    rhs.coeff,
+                    rhs.n_frac_digits,
                 ) {
                     Ok((coeff, n_frac_digits)) => Self::Output {
                         coeff,
@@ -294,16 +290,16 @@ mod div_integer_tests {
                 let d = Decimal::new_raw($num, $p);
                 let i: $t = $den;
                 let r = d / i;
-                assert_eq!(r.coeff, $quot);
+                assert_eq!(r.coefficient(), $quot);
                 assert_eq!(r.n_frac_digits(), $q);
-                assert_eq!(r.coeff, (&d / i).coeff);
-                assert_eq!(r.coeff, (d / &i).coeff);
-                assert_eq!(r.coeff, (&d / &i).coeff);
+                assert_eq!(r.coefficient(), (&d / i).coefficient());
+                assert_eq!(r.coefficient(), (d / &i).coefficient());
+                assert_eq!(r.coefficient(), (&d / &i).coefficient());
                 let z = i / d;
                 assert_eq!(z, 1 / r);
-                assert_eq!(z.coeff, (&i / d).coeff);
-                assert_eq!(z.coeff, (i / &d).coeff);
-                assert_eq!(z.coeff, (&i / &d).coeff);
+                assert_eq!(z.coefficient(), (&i / d).coefficient());
+                assert_eq!(z.coefficient(), (i / &d).coefficient());
+                assert_eq!(z.coefficient(), (&i / &d).coefficient());
             }
         };
     }
@@ -331,8 +327,8 @@ mod div_integer_tests {
         let x = Decimal::new_raw(0, 3);
         let y = 123_i64;
         let z = x / y;
-        assert_eq!(z.coeff, 0);
-        assert_eq!(z.n_frac_digits, 0);
+        assert_eq!(z.coefficient(), 0);
+        assert_eq!(z.n_frac_digits(), 0);
     }
 
     #[test]
@@ -340,8 +336,8 @@ mod div_integer_tests {
         let x = 0_u32;
         let y = Decimal::new_raw(1234567, 3);
         let z = x / y;
-        assert_eq!(z.coeff, 0);
-        assert_eq!(z.n_frac_digits, 0);
+        assert_eq!(z.coefficient(), 0);
+        assert_eq!(z.n_frac_digits(), 0);
     }
 
     #[test]
@@ -349,12 +345,12 @@ mod div_integer_tests {
         let x = Decimal::new_raw(17, 5);
         let y = 1_i64;
         let z = x / y;
-        assert_eq!(z.coeff, 17);
-        assert_eq!(z.n_frac_digits, 5);
+        assert_eq!(z.coefficient(), 17);
+        assert_eq!(z.n_frac_digits(), 5);
         let y = 1_u8;
         let z = x / y;
-        assert_eq!(z.coeff, 17);
-        assert_eq!(z.n_frac_digits, 5);
+        assert_eq!(z.coefficient(), 17);
+        assert_eq!(z.n_frac_digits(), 5);
     }
 
     #[test]
@@ -362,13 +358,13 @@ mod div_integer_tests {
         let x = 17;
         let y = Decimal::ONE;
         let z: Decimal = x / y;
-        assert_eq!(z.coeff, 17);
-        assert_eq!(z.n_frac_digits, 0);
+        assert_eq!(z.coefficient(), 17);
+        assert_eq!(z.n_frac_digits(), 0);
         let x = 1_u64;
         let y = Decimal::new_raw(1000, 3);
         let z = x / y;
-        assert_eq!(z.coeff, 1);
-        assert_eq!(z.n_frac_digits, 0);
+        assert_eq!(z.coefficient(), 1);
+        assert_eq!(z.n_frac_digits(), 0);
     }
 
     #[test]
@@ -422,14 +418,14 @@ mod div_assign_tests {
     fn test_div_assign_decimal() {
         let mut x = Decimal::new_raw(1234567890, 9);
         x /= Decimal::new_raw(5000, 3);
-        assert_eq!(x.coeff, 123456789 * 2);
+        assert_eq!(x.coefficient(), 123456789 * 2);
     }
 
     #[test]
     fn test_div_assign_int() {
         let mut x = Decimal::new_raw(1234567890, 9);
         x /= -10_i64;
-        assert_eq!(x.coeff, -123456789);
+        assert_eq!(x.coefficient(), -123456789);
     }
 
     #[test]
