@@ -5,9 +5,9 @@
 //              with the application.
 // ---------------------------------------------------------------------------
 // $Source: src/binops/div_rounded.rs $
-// $Revision: 2021-11-25T12:32:16+01:00 $
+// $Revision: 2022-01-02T11:24:00+01:00 $
 
-use std::cmp::{min, Ordering};
+use core::cmp::{min, Ordering};
 
 use fpdec_core::{checked_mul_pow_ten, magnitude, ten_pow};
 
@@ -21,7 +21,30 @@ pub trait DivRounded<Rhs = Self> {
     /// The resulting type after applying `div_rounded`.
     type Output;
 
-    /// Returns `self` / `other`, rounded to `n_frac_digits`.
+    /// Returns `self` / `rhs`, rounded to `n_frac_digits`, according to the
+    /// current [RoundingMode](crate::RoundingMode).
+    ///
+    /// # Panics
+    ///
+    /// Panics if `rhs` equals zero or the resulting value can not be
+    /// represented by `Self::Output`!
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # use fpdec::{Dec, Decimal, DivRounded};
+    /// let divident = -322_i32;
+    /// let divisor = 3_i32;
+    /// let res = divident.div_rounded(divisor, 0);
+    /// assert_eq!(res.to_string(), "-107");
+    /// let d = Dec!(28.27093);
+    /// let q = 5_u32;
+    /// let r = d.div_rounded(q, 4);
+    /// assert_eq!(r.to_string(), "5.6542");
+    /// let q = Dec!(0.03);
+    /// let r = d.div_rounded(q, 3);
+    /// assert_eq!(r.to_string(), "942.364");
+    /// ```
     fn div_rounded(self, rhs: Rhs, n_frac_digits: u8) -> Self::Output;
 }
 
@@ -94,8 +117,8 @@ fn div_rounded(
 impl DivRounded<Decimal> for Decimal {
     type Output = Self;
 
-    fn div_rounded(self, other: Decimal, n_frac_digits: u8) -> Self::Output {
-        if other.eq_zero() {
+    fn div_rounded(self, rhs: Decimal, n_frac_digits: u8) -> Self::Output {
+        if rhs.eq_zero() {
             panic!("{}", DecimalError::DivisionByZero);
         }
         if self.eq_zero() {
@@ -104,8 +127,8 @@ impl DivRounded<Decimal> for Decimal {
         let coeff = div_rounded(
             self.coeff,
             self.n_frac_digits,
-            other.coeff,
-            other.n_frac_digits,
+            rhs.coeff,
+            rhs.n_frac_digits,
             n_frac_digits,
         );
         Self::Output {
@@ -128,23 +151,39 @@ mod div_rounded_decimal_tests {
         let x = Decimal::new_raw(17, 0);
         let y = Decimal::new_raw(-201, 2);
         let z = x.div_rounded(y, 2);
-        assert_eq!(z.coeff, -846);
-        assert_eq!(z.n_frac_digits, 2);
+        assert_eq!(z.coefficient(), -846);
+        assert_eq!(z.n_frac_digits(), 2);
         let x = Decimal::new_raw(17654321, 8);
         let y = Decimal::new_raw(204, 3);
         let z = x.div_rounded(y, 2);
-        assert_eq!(z.coeff, 87);
-        assert_eq!(z.n_frac_digits, 2);
+        assert_eq!(z.coefficient(), 87);
+        assert_eq!(z.n_frac_digits(), 2);
         let x = Decimal::new_raw(12345678901234567890, 2);
         let y = Decimal::new_raw(244140625, 6);
         let z = x.div_rounded(y, 9);
-        assert_eq!(z.coeff, 505679007794567900774400);
-        assert_eq!(z.n_frac_digits, 9);
+        assert_eq!(z.coefficient(), 505679007794567900774400);
+        assert_eq!(z.n_frac_digits(), 9);
         let x = Decimal::new_raw(1234567, 5);
         let y = Decimal::new_raw(625, 2);
         let z = x.div_rounded(y, 3);
-        assert_eq!(z.coeff, 1975);
-        assert_eq!(z.n_frac_digits, 3);
+        assert_eq!(z.coefficient(), 1975);
+        assert_eq!(z.n_frac_digits(), 3);
+    }
+
+    #[test]
+    fn test_div_rounded_to_int() {
+        let x = Decimal::new_raw(17, 0);
+        let y = Decimal::new_raw(200, 2);
+        let z = x.div_rounded(y, 0);
+        assert_eq!(z.coefficient(), 8);
+        assert_eq!(z.n_frac_digits(), 0);
+        let y = Decimal::new_raw(3, 0);
+        let z = x.div_rounded(y, 0);
+        assert_eq!(z.coefficient(), 6);
+        let x = Decimal::new_raw(170000, 4);
+        let y = Decimal::new_raw(3, 0);
+        let z = x.div_rounded(y, 0);
+        assert_eq!(z.coefficient(), 6);
     }
 
     #[test]
@@ -152,11 +191,11 @@ mod div_rounded_decimal_tests {
         let x = Decimal::new_raw(0, 5);
         let y = Decimal::new_raw(17, 1);
         let z = x.div_rounded(y, 3);
-        assert_eq!(z.coeff, 0);
-        assert_eq!(z.n_frac_digits, 0);
+        assert_eq!(z.coefficient(), 0);
+        assert_eq!(z.n_frac_digits(), 0);
         let z = x.div_rounded(y, 29);
-        assert_eq!(z.coeff, 0);
-        assert_eq!(z.n_frac_digits, 0);
+        assert_eq!(z.coefficient(), 0);
+        assert_eq!(z.n_frac_digits(), 0);
     }
 
     #[test]
@@ -164,12 +203,12 @@ mod div_rounded_decimal_tests {
         let x = Decimal::new_raw(17, 5);
         let y = Decimal::ONE;
         let z = x.div_rounded(y, 4);
-        assert_eq!(z.coeff, 2);
-        assert_eq!(z.n_frac_digits, 4);
+        assert_eq!(z.coefficient(), 2);
+        assert_eq!(z.n_frac_digits(), 4);
         let y = Decimal::new_raw(1000000000, 9);
         let z = x.div_rounded(y, 6);
-        assert_eq!(z.coeff, 170);
-        assert_eq!(z.n_frac_digits, 6);
+        assert_eq!(z.coefficient(), 170);
+        assert_eq!(z.n_frac_digits(), 6);
     }
 
     // corner case: shifting divident overflows, stepwise algorithm must be used
@@ -178,8 +217,8 @@ mod div_rounded_decimal_tests {
         let x = Decimal::new_raw(13, 1);
         let y = Decimal::new_raw(20, 29);
         let z = x.div_rounded(y, 10);
-        assert_eq!(z.coeff, 65000000000000000000000000000000000000);
-        assert_eq!(z.n_frac_digits, 10);
+        assert_eq!(z.coefficient(), 65000000000000000000000000000000000000);
+        assert_eq!(z.n_frac_digits(), 10);
     }
 
     #[test]
@@ -204,11 +243,11 @@ mod div_rounded_decimal_tests {
         let y = Decimal::new_raw(12345, 4);
         let z = x.div_rounded(y, 2);
         let a = DivRounded::div_rounded(&x, y, 2);
-        assert_eq!(a.coeff, z.coeff);
+        assert_eq!(a.coefficient(), z.coefficient());
         let a = DivRounded::div_rounded(x, &y, 2);
-        assert_eq!(a.coeff, z.coeff);
+        assert_eq!(a.coefficient(), z.coefficient());
         let a = DivRounded::div_rounded(&x, &y, 2);
-        assert_eq!(a.coeff, z.coeff);
+        assert_eq!(a.coefficient(), z.coefficient());
     }
 }
 
@@ -223,8 +262,8 @@ macro_rules! impl_div_rounded_decimal_and_int {
         impl DivRounded<$t> for Decimal {
             type Output = Self;
 
-            fn div_rounded(self, other: $t, n_frac_digits: u8) -> Self::Output {
-                if other == 0 {
+            fn div_rounded(self, rhs: $t, n_frac_digits: u8) -> Self::Output {
+                if rhs == 0 {
                     panic!("{}", DecimalError::DivisionByZero);
                 }
                 if self.eq_zero() {
@@ -233,7 +272,7 @@ macro_rules! impl_div_rounded_decimal_and_int {
                 let coeff = div_rounded(
                     self.coeff,
                     self.n_frac_digits,
-                    other as i128,
+                    rhs as i128,
                     0_u8,
                     n_frac_digits,
                 );
@@ -251,8 +290,8 @@ macro_rules! impl_div_rounded_decimal_and_int {
             type Output = <Decimal as DivRounded<$t>>::Output;
 
             #[inline(always)]
-            fn div_rounded(self, other: $t, n_frac_digits: u8) -> Self::Output {
-                DivRounded::div_rounded(*self, other, n_frac_digits)
+            fn div_rounded(self, rhs: $t, n_frac_digits: u8) -> Self::Output {
+                DivRounded::div_rounded(*self, rhs, n_frac_digits)
             }
         }
 
@@ -263,8 +302,8 @@ macro_rules! impl_div_rounded_decimal_and_int {
             type Output = <Decimal as DivRounded<$t>>::Output;
 
             #[inline(always)]
-            fn div_rounded(self, other: &$t, n_frac_digits: u8) -> Self::Output {
-                DivRounded::div_rounded(self, *other, n_frac_digits)
+            fn div_rounded(self, rhs: &$t, n_frac_digits: u8) -> Self::Output {
+                DivRounded::div_rounded(self, *rhs, n_frac_digits)
             }
         }
 
@@ -275,16 +314,16 @@ macro_rules! impl_div_rounded_decimal_and_int {
             type Output = <Decimal as DivRounded<$t>>::Output;
 
             #[inline(always)]
-            fn div_rounded(self, other: &$t, n_frac_digits: u8) -> Self::Output {
-                DivRounded::div_rounded(*self, *other, n_frac_digits)
+            fn div_rounded(self, rhs: &$t, n_frac_digits: u8) -> Self::Output {
+                DivRounded::div_rounded(*self, *rhs, n_frac_digits)
             }
         }
 
         impl DivRounded<Decimal> for $t {
             type Output = Decimal;
 
-            fn div_rounded(self, other: Decimal, n_frac_digits: u8) -> Self::Output {
-                if other.eq_zero() {
+            fn div_rounded(self, rhs: Decimal, n_frac_digits: u8) -> Self::Output {
+                if rhs.eq_zero() {
                     panic!("{}", DecimalError::DivisionByZero);
                 }
                 if self == 0 {
@@ -293,8 +332,8 @@ macro_rules! impl_div_rounded_decimal_and_int {
                 let coeff = div_rounded(
                     self as i128,
                     0_u8,
-                    other.coeff,
-                    other.n_frac_digits,
+                    rhs.coeff,
+                    rhs.n_frac_digits,
                     n_frac_digits,
                 );
                 Self::Output {
@@ -311,8 +350,8 @@ macro_rules! impl_div_rounded_decimal_and_int {
             type Output = <$t as DivRounded<Decimal>>::Output;
 
             #[inline(always)]
-            fn div_rounded(self, other: Decimal, n_frac_digits: u8) -> Self::Output {
-                DivRounded::div_rounded(*self, other, n_frac_digits)
+            fn div_rounded(self, rhs: Decimal, n_frac_digits: u8) -> Self::Output {
+                DivRounded::div_rounded(*self, rhs, n_frac_digits)
             }
         }
 
@@ -323,8 +362,8 @@ macro_rules! impl_div_rounded_decimal_and_int {
             type Output = <$t as DivRounded<Decimal>>::Output;
 
             #[inline(always)]
-            fn div_rounded(self, other: &Decimal, n_frac_digits: u8) -> Self::Output {
-                DivRounded::div_rounded(self, *other, n_frac_digits)
+            fn div_rounded(self, rhs: &Decimal, n_frac_digits: u8) -> Self::Output {
+                DivRounded::div_rounded(self, *rhs, n_frac_digits)
             }
         }
 
@@ -335,8 +374,8 @@ macro_rules! impl_div_rounded_decimal_and_int {
             type Output = <$t as DivRounded<Decimal>>::Output;
 
             #[inline(always)]
-            fn div_rounded(self, other: &Decimal, n_frac_digits: u8) -> Self::Output {
-                DivRounded::div_rounded(*self, *other, n_frac_digits)
+            fn div_rounded(self, rhs: &Decimal, n_frac_digits: u8) -> Self::Output {
+                DivRounded::div_rounded(*self, *rhs, n_frac_digits)
             }
         }
         )*
@@ -358,17 +397,17 @@ mod div_rounded_decimal_by_int_tests {
                 let d = Decimal::new_raw($coeff, $p);
                 let i = $i;
                 let r = d.div_rounded(i, $r);
-                assert_eq!(r.coeff, $res_coeff);
-                assert_eq!(r.n_frac_digits, $r);
+                assert_eq!(r.coefficient(), $res_coeff);
+                assert_eq!(r.n_frac_digits(), $r);
                 let r = (&d).div_rounded(i, $r);
-                assert_eq!(r.coeff, $res_coeff);
-                assert_eq!(r.n_frac_digits, $r);
+                assert_eq!(r.coefficient(), $res_coeff);
+                assert_eq!(r.n_frac_digits(), $r);
                 let r = d.div_rounded(&i, $r);
-                assert_eq!(r.coeff, $res_coeff);
-                assert_eq!(r.n_frac_digits, $r);
+                assert_eq!(r.coefficient(), $res_coeff);
+                assert_eq!(r.n_frac_digits(), $r);
                 let r = (&d).div_rounded(&i, $r);
-                assert_eq!(r.coeff, $res_coeff);
-                assert_eq!(r.n_frac_digits, $r);
+                assert_eq!(r.coefficient(), $res_coeff);
+                assert_eq!(r.n_frac_digits(), $r);
             }
         };
     }
@@ -411,8 +450,8 @@ mod div_rounded_decimal_by_int_tests {
         let x = Decimal::new_raw(0, 3);
         let y = 123_i64;
         let z = x.div_rounded(y, 2);
-        assert_eq!(z.coeff, 0);
-        assert_eq!(z.n_frac_digits, 0);
+        assert_eq!(z.coefficient(), 0);
+        assert_eq!(z.n_frac_digits(), 0);
     }
 
     #[test]
@@ -420,8 +459,8 @@ mod div_rounded_decimal_by_int_tests {
         let x = 0_u32;
         let y = Decimal::new_raw(1234567, 3);
         let z = x.div_rounded(y, 13);
-        assert_eq!(z.coeff, 0);
-        assert_eq!(z.n_frac_digits, 0);
+        assert_eq!(z.coefficient(), 0);
+        assert_eq!(z.n_frac_digits(), 0);
     }
 
     #[test]
@@ -429,16 +468,16 @@ mod div_rounded_decimal_by_int_tests {
         let x = Decimal::new_raw(17, 5);
         let y = 1_i64;
         let z = x.div_rounded(y, 5);
-        assert_eq!(z.coeff, 17);
-        assert_eq!(z.n_frac_digits, 5);
+        assert_eq!(z.coefficient(), 17);
+        assert_eq!(z.n_frac_digits(), 5);
         let y = 1_u8;
         let z = x.div_rounded(y, 7);
-        assert_eq!(z.coeff, 1700);
-        assert_eq!(z.n_frac_digits, 7);
+        assert_eq!(z.coefficient(), 1700);
+        assert_eq!(z.n_frac_digits(), 7);
         let y = 1_i32;
         let z = x.div_rounded(y, 4);
-        assert_eq!(z.coeff, 2);
-        assert_eq!(z.n_frac_digits, 4);
+        assert_eq!(z.coefficient(), 2);
+        assert_eq!(z.n_frac_digits(), 4);
     }
 
     #[test]
@@ -446,13 +485,13 @@ mod div_rounded_decimal_by_int_tests {
         let x = 17;
         let y = Decimal::ONE;
         let z: Decimal = x.div_rounded(y, 0);
-        assert_eq!(z.coeff, 17);
-        assert_eq!(z.n_frac_digits, 0);
+        assert_eq!(z.coefficient(), 17);
+        assert_eq!(z.n_frac_digits(), 0);
         let x = 1_u64;
         let y = Decimal::new_raw(1000, 3);
         let z = x.div_rounded(y, 2);
-        assert_eq!(z.coeff, 100);
-        assert_eq!(z.n_frac_digits, 2);
+        assert_eq!(z.coefficient(), 100);
+        assert_eq!(z.n_frac_digits(), 2);
     }
 
     // corner case: shifting divident overflows, stepwise algorithm must be used
@@ -461,8 +500,8 @@ mod div_rounded_decimal_by_int_tests {
         let x = Decimal::new_raw(i128::MAX, 0);
         let y = Decimal::new_raw(20, 0);
         let z = x.div_rounded(y, 1);
-        assert_eq!(z.coeff, (i128::MAX / 20) * 10 + 4);
-        assert_eq!(z.n_frac_digits, 1);
+        assert_eq!(z.coefficient(), (i128::MAX / 20) * 10 + 4);
+        assert_eq!(z.n_frac_digits(), 1);
     }
 
     #[test]
@@ -487,17 +526,17 @@ mod div_rounded_int_by_decimal_tests {
                 let d = Decimal::new_raw($coeff, $p);
                 let i = $i;
                 let r = i.div_rounded(d, $r);
-                assert_eq!(r.coeff, $res_coeff);
-                assert_eq!(r.n_frac_digits, $r);
+                assert_eq!(r.coefficient(), $res_coeff);
+                assert_eq!(r.n_frac_digits(), $r);
                 let r = (&i).div_rounded(d, $r);
-                assert_eq!(r.coeff, $res_coeff);
-                assert_eq!(r.n_frac_digits, $r);
+                assert_eq!(r.coefficient(), $res_coeff);
+                assert_eq!(r.n_frac_digits(), $r);
                 let r = i.div_rounded(&d, $r);
-                assert_eq!(r.coeff, $res_coeff);
-                assert_eq!(r.n_frac_digits, $r);
+                assert_eq!(r.coefficient(), $res_coeff);
+                assert_eq!(r.n_frac_digits(), $r);
                 let r = (&i).div_rounded(&d, $r);
-                assert_eq!(r.coeff, $res_coeff);
-                assert_eq!(r.n_frac_digits, $r);
+                assert_eq!(r.coefficient(), $res_coeff);
+                assert_eq!(r.n_frac_digits(), $r);
             }
         };
     }
@@ -558,3 +597,141 @@ mod div_rounded_int_by_decimal_tests {
         let _z = x.div_rounded(y, 5);
     }
 }
+
+macro_rules! impl_div_rounded_int_and_int {
+    () => {
+        impl_div_rounded_int_and_int!(
+            u8, i8, u16, i16, u32, i32, u64, i64, i128
+        );
+    };
+    ($($t:ty),*) => {
+        $(
+        impl DivRounded<$t> for $t {
+            type Output = Decimal;
+
+            fn div_rounded(self, rhs: $t, n_frac_digits: u8) -> Self::Output {
+                if rhs == 0 {
+                    panic!("{}", DecimalError::DivisionByZero);
+                }
+                if self == 0 {
+                    return Decimal::ZERO;
+                }
+                let coeff = div_rounded(
+                    self as i128,
+                    0_u8,
+                    rhs as i128,
+                    0_u8,
+                    n_frac_digits,
+                );
+                Self::Output {
+                    coeff,
+                    n_frac_digits,
+                }
+            }
+        }
+
+        impl<'a> DivRounded<$t> for &'a $t
+        where
+            $t: DivRounded<$t>,
+        {
+            type Output = <$t as DivRounded<$t>>::Output;
+
+            #[inline(always)]
+            fn div_rounded(self, rhs: $t, n_frac_digits: u8) -> Self::Output {
+                DivRounded::div_rounded(*self, rhs, n_frac_digits)
+            }
+        }
+
+        impl DivRounded<&$t> for $t
+        where
+            $t: DivRounded<$t>,
+        {
+            type Output = <$t as DivRounded<$t>>::Output;
+
+            #[inline(always)]
+            fn div_rounded(self, rhs: &$t, n_frac_digits: u8) -> Self::Output {
+                DivRounded::div_rounded(self, *rhs, n_frac_digits)
+            }
+        }
+
+        impl DivRounded<&$t> for &$t
+        where
+            $t: DivRounded<$t>,
+        {
+            type Output = <$t as DivRounded<$t>>::Output;
+
+            #[inline(always)]
+            fn div_rounded(self, rhs: &$t, n_frac_digits: u8) -> Self::Output {
+                DivRounded::div_rounded(*self, *rhs, n_frac_digits)
+            }
+        }
+        )*
+    }
+}
+
+impl_div_rounded_int_and_int!();
+
+#[cfg(test)]
+#[allow(clippy::neg_multiply)]
+mod div_rounded_int_by_int_tests {
+    use super::*;
+
+    macro_rules! gen_div_rounded_int_by_int_tests {
+        ($func:ident, $i:expr, $j:expr, $r:expr,
+         $res_coeff:expr) => {
+            #[test]
+            fn $func() {
+                let i = $i;
+                let j = $j;
+                let r = i.div_rounded(j, $r);
+                assert_eq!(r.coefficient(), $res_coeff);
+                assert_eq!(r.n_frac_digits(), $r);
+                let r = (&i).div_rounded(j, $r);
+                assert_eq!(r.coefficient(), $res_coeff);
+                assert_eq!(r.n_frac_digits(), $r);
+                let r = i.div_rounded(&j, $r);
+                assert_eq!(r.coefficient(), $res_coeff);
+                assert_eq!(r.n_frac_digits(), $r);
+                let r = (&i).div_rounded(&j, $r);
+                assert_eq!(r.coefficient(), $res_coeff);
+                assert_eq!(r.n_frac_digits(), $r);
+            }
+        };
+    }
+
+    gen_div_rounded_int_by_int_tests!(test_u8, 44_u8, 3_u8, 5, 1466667);
+    gen_div_rounded_int_by_int_tests!(test_i8, -12_i8, -3_i8, 4, 40000);
+    gen_div_rounded_int_by_int_tests!(test_u16, 17_u16, 4_u16, 3, 4250);
+    gen_div_rounded_int_by_int_tests!(test_i16, -22, -13_i16, 7, 16923077);
+    gen_div_rounded_int_by_int_tests!(test_u32, u32::MAX, 10_u32, 0, 429496730);
+    gen_div_rounded_int_by_int_tests!(test_i32, 12345_i32, -328_i32, 1, -376);
+    gen_div_rounded_int_by_int_tests!(
+        test_u64,
+        1_u64,
+        4294967295_u64,
+        32,
+        23283064370807973754315
+    );
+    gen_div_rounded_int_by_int_tests!(
+        test_i64,
+        i64::MIN,
+        u32::MAX as i64,
+        2,
+        -214748364850
+    );
+    gen_div_rounded_int_by_int_tests!(
+        test_i128,
+        987654321987654321_i128,
+        1234567890_i128,
+        1,
+        8000000081
+    );
+
+    #[test]
+    #[should_panic]
+    fn test_div_rounded_int_by_int_zero() {
+        let x = 17_u16;
+        let y = 0_u16;
+        let _z = x.div_rounded(y, 5);
+    }
+}
