@@ -5,12 +5,15 @@
 //              with the application.
 // ---------------------------------------------------------------------------
 // $Source: src/lib.rs $
-// $Revision: 2021-12-05T18:34:29+01:00 $
+// $Revision: 2022-01-02T08:39:05+01:00 $
 
 #![doc = include_str ! ("../README.md")]
+#![cfg_attr(not(feature = "std"), no_std)]
 #![allow(dead_code)]
 #![warn(missing_docs)]
 
+#[doc(inline)]
+pub use as_integer_ratio::AsIntegerRatio;
 #[doc(inline)]
 pub use binops::{
     checked_add_sub::CheckedAdd, checked_add_sub::CheckedSub,
@@ -25,14 +28,18 @@ pub use fpdec_core::{ParseDecimalError, MAX_N_FRAC_DIGITS};
 #[doc(inline)]
 pub use fpdec_macros::Dec;
 #[doc(inline)]
+pub use quantize::Quantize;
+#[doc(inline)]
 pub use rounding::{Round, RoundingMode};
 
+mod as_integer_ratio;
 mod binops;
 mod errors;
 mod format;
 mod from_float;
 mod from_int;
 mod from_str;
+mod quantize;
 mod rounding;
 #[cfg(feature = "num-traits")]
 mod traits;
@@ -43,7 +50,7 @@ mod unops;
 ///
 /// The number of fractional digits can be in the range 0 ..
 /// [`MAX_N_FRAC_DIGITS`].
-#[derive(Copy, Clone, Eq, Ord)]
+#[derive(Copy, Clone)]
 #[cfg_attr(feature = "packed", repr(packed))]
 pub struct Decimal {
     coeff: i128,
